@@ -101,7 +101,7 @@ class PGG_diffusion:
 
         cost_i = 0
         for i in self._G.neighbors(dealer):
-            if self._G.node[i]['strategy'] == 'C' and self._G.edge[i][dealer]['ready_to_sent'] == 1:
+            if self._G.node[i]['strategy'] == 'C' and self._G.node[i]['ready_to_sent'] == 1:
                 Nj = [self._G.node[nd]['strategy'] for nd in self._G.neighbors(i)].count('C')
                 cost_i += 1.0 / (Nj + 1)
 
@@ -127,7 +127,7 @@ class PGG_diffusion:
                             if not pkt in H.node[neighbor]['time_stamp']:
                                 H.node[neighbor]['time_stamp'].append(pkt)
                                 H.node[neighbor]['state'] = 'I'
-                            H.edge[node][neighbor]['ready_to_sent'] = 1
+                            H.node[node]['ready_to_sent'] = 1
         self._G = H.copy()
 
     def run_game(self, nb_simulation_step=None):
@@ -226,8 +226,7 @@ class PGG_diffusion:
 
     def set_sent_update(self, sent_update):
        for (key, val) in sent_update.iteritems():
-            s,d = key
-            self._G.edge[s][d]['ready_to_sent'] = val
+            self._G.node[key]['ready_to_sent'] = val
 
     #
     # Get
@@ -267,8 +266,8 @@ class PGG_diffusion:
 
     def get_sent_update(self):
         sent_update = {}
-        for s,d in self._G.edges_iter():
-            sent_update[(s,d)] = self._G.edge[s][d]['ready_to_sent']
+        for nd in self._G.nodes_iter():
+            sent_update[nd] = self._G.node[nd]['ready_to_sent']
         return sent_update
 
     def get_seeder(self):
@@ -286,8 +285,8 @@ class PGG_diffusion:
         self._G.node[player]['payoff'] = 0.0
 
     def reset_send_update(self):
-        for s,d in self._G.edges_iter():
-            self._G.edge[s][d]['ready_to_sent'] = 0
+        for nd in self._G.nodes_iter():
+            self._G.node[nd]['ready_to_sent'] = 0
 
 
     #
